@@ -29,13 +29,14 @@
 //!     Ok(())
 //! }
 //! ```
+#![allow(clippy::return_self_not_must_use)]
+
 mod client;
 pub mod cmd;
 pub mod codec;
 mod connector;
 pub mod errors;
 mod simple;
-// mod transport;
 
 pub use self::client::{Client, CommandResult};
 pub use self::connector::RedisConnector;
